@@ -6,7 +6,7 @@ mod float_types;
 mod int_types;
 mod mem;
 mod platform;
-mod view;
+mod slice;
 pub use arch::*;
 pub use char_types::*;
 pub use def::*;
@@ -14,4 +14,4 @@ pub use float_types::*;
 pub use int_types::*;
 pub use mem::*;
 pub use platform::*;
-pub use view::*;
+pub use slice::*;
